@@ -1,3 +1,5 @@
+from typing import Any
+
 from .crf import CrfRuleGroup
 from .requisition import RequisitionRuleGroup
 from .site import site_metadata_rules
@@ -7,11 +9,11 @@ class RegisterRuleGroupError(Exception):
     pass
 
 
-def register(site=None, **kwargs):
+def register(site=None, **kwargs) -> Any:  # noqa
     """Registers a rule group."""
     site = site or site_metadata_rules
 
-    def _rule_group_wrapper(rule_group_cls):
+    def _rule_group_wrapper(rule_group_cls: Any) -> Any:
 
         if not issubclass(rule_group_cls, (CrfRuleGroup, RequisitionRuleGroup)):
             raise RegisterRuleGroupError(
