@@ -20,9 +20,7 @@ class RequisitionRuleGroupMetaOptions(RuleGroupMetaOptions):
         super().__init__(group_name, attrs)
         self.requisition_model = self.options.get("requisition_model")
         if self.requisition_model:
-            try:
-                assert len(self.requisition_model.split(".")) == 2
-            except AssertionError:
+            if len(self.requisition_model.split(".")) != 2:
                 self.requisition_model = f"{self.app_label}.{self.requisition_model}"
                 self.options.update(requisition_model=self.requisition_model)
             self.options.update(target_models=[self.requisition_model])
