@@ -1,7 +1,7 @@
 from collections import OrderedDict
 
 from django.contrib.auth.models import User
-from django.test import TestCase, tag
+from django.test import TestCase
 from django.test.client import RequestFactory
 from edc_appointment.models import Appointment
 from edc_facility import import_holidays
@@ -13,21 +13,20 @@ from edc_visit_schedule import site_visit_schedules
 from edc_visit_tracking.constants import SCHEDULED
 
 from edc_metadata import site_metadata_rules
+from edc_metadata.metadata_helper import MetadataHelperMixin
+from edc_metadata.models import CrfMetadata, RequisitionMetadata
 
-from ...metadata_helper_mixin import MetaDataHelperMixin
-from ...models import CrfMetadata, RequisitionMetadata
 from ..models import SubjectConsent, SubjectVisit
 from ..reference_configs import register_to_site_reference_configs
 from ..visit_schedule import visit_schedule
 from .test_view_mixin import MyView
 
 
-class MyForm(MetaDataHelperMixin, FormValidator):
+class MyForm(MetadataHelperMixin, FormValidator):
 
     pass
 
 
-@tag("12")
 class TestForm(TestCase):
     @classmethod
     def setUpTestData(cls):
