@@ -11,11 +11,11 @@ from ..constants import CRF, KEYED, NOT_REQUIRED, REQUIRED, REQUISITION
 from ..metadata_wrappers import CrfMetadataWrappers, RequisitionMetadataWrappers
 
 
-class MetaDataViewError(Exception):
+class MetadataViewError(Exception):
     pass
 
 
-class MetaDataViewMixin(MessageViewMixin, ContextMixin):
+class MetadataViewMixin(MessageViewMixin, ContextMixin):
 
     crf_model_wrapper_cls = CrfModelWrapper
     requisition_model_wrapper_cls = RequisitionModelWrapper
@@ -31,21 +31,26 @@ class MetaDataViewMixin(MessageViewMixin, ContextMixin):
         if self.appointment:
             if self.appointment.appt_status != IN_PROGRESS_APPT:
                 message = _(
-                    'You have selected a visit that is no longer "in progress". '
-                    "Refer to the schedule for the visit that is "
+                    'You have selected an appointment that is no longer "in progress". '
+                    "Refer to the schedule for the appointment that is "
                     'currently "in progress".'
                 )
                 self.message_user(message, level=messages.WARNING)
 
             crf_model_wrappers = self.get_crf_model_wrappers()
-            context.update(
-                report_datetime=self.appointment.visit.report_datetime,
-                crfs=crf_model_wrappers,
-                requisitions=self.get_requisition_model_wrapper(),
-                NOT_REQUIRED=NOT_REQUIRED,
-                REQUIRED=REQUIRED,
-                KEYED=KEYED,
-            )
+            try:
+                report_datetime = self.appointment.related_visit.report_datetime
+            except AttributeError:
+                pass
+            else:
+                context.update(
+                    report_datetime=report_datetime,
+                    crfs=crf_model_wrappers,
+                    requisitions=self.get_requisition_model_wrapper(),
+                    NOT_REQUIRED=NOT_REQUIRED,
+                    REQUIRED=REQUIRED,
+                    KEYED=KEYED,
+                )
         return context
 
     def get_crf_model_wrappers(self):
@@ -55,7 +60,11 @@ class MetaDataViewMixin(MessageViewMixin, ContextMixin):
         for metadata_wrapper in crf_metadata_wrappers.objects:
             if not metadata_wrapper.model_obj:
                 metadata_wrapper.model_obj = metadata_wrapper.model_cls(
-                    **{metadata_wrapper.model_cls.visit_model_attr(): metadata_wrapper.visit}
+                    **{
+                        metadata_wrapper.model_cls.related_visit_model_attr(): (
+                            metadata_wrapper.visit
+                        )
+                    }
                 )
             metadata_wrapper.metadata_obj.object = self.crf_model_wrapper_cls(
                 model_obj=metadata_wrapper.model_obj,
@@ -81,7 +90,9 @@ class MetaDataViewMixin(MessageViewMixin, ContextMixin):
                 panel = self.get_panel(metadata_wrapper)
                 metadata_wrapper.model_obj = metadata_wrapper.model_cls(
                     **{
-                        metadata_wrapper.model_cls.visit_model_attr(): metadata_wrapper.visit,
+                        metadata_wrapper.model_cls.related_visit_model_attr(): (
+                            metadata_wrapper.visit
+                        ),
                         "panel": panel,
                     }
                 )
@@ -102,7 +113,7 @@ class MetaDataViewMixin(MessageViewMixin, ContextMixin):
         try:
             panel = self.panel_model_cls.objects.get(name=metadata_wrapper.panel_name)
         except ObjectDoesNotExist as e:
-            raise MetaDataViewError(
+            raise MetadataViewError(
                 f"{e} Got panel name '{metadata_wrapper.panel_name}'. "
                 f"See {metadata_wrapper}."
             )
