@@ -1,13 +1,13 @@
-from django.conf import settings
 from django.contrib.auth.decorators import login_required
 from django.utils.decorators import method_decorator
 from django.views.generic.base import TemplateView
+from edc_dashboard.utils import get_bootstrap_version
 from edc_dashboard.view_mixins import EdcViewMixin
 
 
 class HomeView(EdcViewMixin, TemplateView):
 
-    template_name = f"edc_metadata/bootstrap{settings.EDC_BOOTSTRAP}/home.html"
+    template_name = f"edc_metadata/bootstrap{get_bootstrap_version()}/home.html"
 
     @method_decorator(login_required)
     def dispatch(self, *args, **kwargs):
